var mongoose = require('mongoose')
    , async = require('async')
    ;
exports = module.exports = transition;

/**
 * transition data between different mongodb
 * this is not mongoexport or mongodump which operating with whole collections/table.
 * but from business perspective,the developer could operate the data as flexible as possible to meet the business.
 * @param dbA url
 * @param getData function getData(msg, callback)
 * @param dbB url
 * @param updateData function updateData(msg,objs, callback)
 */
function transition(dbA, getData, dbB, updateData) {


    var loadFromA = function (callback1) {
        async.waterfall(
            [
                function dbConnect(callback) {
                    mongoose.connect(dbA, null, function (err) {
                        callback(err, 'connect success:' + dbA);
                    });
                },
                getData,
                function closeConnect(msg, docs, callback) {
                    console.log(msg);
                    mongoose.connection.close(function () {
                        callback(null, docs);
                    });
                },
            ], function (err, result) {
                if (err) {
                    console.log('load data failed:', err);
                }
                else {
                    console.log('load data sucess!');
                }
                callback1(err, result);
            }
        )
    };
    var updateB = function (sheets, callback) {
        async.waterfall(
            [
                function dbConnect(callback) {
                    mongoose.connect(dbB, null, function (err) {
                        callback(err,  'connect success:' + dbB, sheets);
                    });
                },
                updateData,
                function closeConnect(msg, callback) {
                    console.log(msg);
                    mongoose.connection.close(function () {
                        callback(null);
                    });
                },
            ]
        )
    };
    var call = function () {
        console.log("*****begin load from A to B!");
        loadFromA(updateB);
    }
    async.waterfall(
        [loadFromA,
         updateB
        ]
        , function (err, result) {
            if (err) {
                console.log('update data failed:', err);
            }
            else {
                console.log('update data sucess!');
            }
        });

}

